package rip.tilly.bedwars;

import lombok.Getter;
import org.bukkit.Bukkit;
import org.bukkit.Chunk;
import org.bukkit.World;
import org.bukkit.entity.Entity;
import org.bukkit.entity.EntityType;
import org.bukkit.plugin.java.JavaPlugin;
import rip.tilly.bedwars.listeners.RandomListeners;
import rip.tilly.bedwars.mongo.MongoManager;
import rip.tilly.bedwars.player.PlayerDataHandler;
import rip.tilly.bedwars.player.PlayerDataManager;
import rip.tilly.bedwars.utils.CC;

import java.util.Arrays;

/**
 * Created by Lucanius & Trixkz
 * Project: BedWars
 */
@Getter
public final class BedWars extends JavaPlugin {

    @Getter private static BedWars instance;

    private MongoManager mongoManager;
    private PlayerDataManager playerDataManager;

    @Override
    public void onEnable() {
        instance = this;

        this.saveDefaultConfig();

        Bukkit.getConsoleSender().sendMessage("------------------------------------------------");
        Bukkit.getConsoleSender().sendMessage(CC.translate("&dBedWars &8- &av" + getDescription().getVersion()));
        Bukkit.getConsoleSender().sendMessage(CC.translate("&7Made on &dTilly RIP &7by &eTrixkz &7& &eLucanius"));
        Bukkit.getConsoleSender().sendMessage("------------------------------------------------");

        this.loadManagers();
        this.loadListeners();

        for (World world : Bukkit.getWorlds()) {
            for (Entity entity : world.getEntities()) {
                if (entity.getType() != EntityType.PLAYER && entity.getType() != EntityType.ITEM_FRAME) {
                    entity.remove();
                }
            }
            world.setGameRuleValue("doDaylightCycle", "false");
            world.setTime(0L);
            world.setStorm(false);
        }
    }

    @Override
    public void onDisable() {
        instance = null;

        for (World world : Bukkit.getWorlds()) {
            for (Entity entity : world.getEntities()) {
                if (entity.getType() == EntityType.DROPPED_ITEM) {
                    entity.remove();
                }
            }
            for (Chunk chunk : world.getLoadedChunks()) {
                chunk.unload(true);
            }
        }

        this.mongoManager.disconnect();
    }

    private void loadManagers() {
        this.mongoManager = new MongoManager();
        this.playerDataManager = new PlayerDataManager();
    }

    private void loadListeners() {
        Arrays.asList(
                new PlayerDataHandler(),
                new RandomListeners()
        ).forEach(listener -> this.getServer().getPluginManager().registerEvents(listener, this));
    }
}
